@@ -7,7 +7,7 @@ use Moo;
 use Hash::Flatten ();
 use Hash::Merge   ();
 
-our $VERSION = '0.000004'; # VERSION
+our $VERSION = '0.000005'; # VERSION
 
 
 sub BUILDARGS {
@@ -117,9 +117,14 @@ sub param {
     $key =~ s/^$dom(\.)?//;
 
     if (@_ > 2) {
-        unless (exists $ENV{$self->to_env_key($key)} && ! $self->override) {
-            $self->load({$self->to_env_key($key) => $val});
-            $self->{registry}{env}{$key} = $val;
+        my $pairs = Hash::Flatten::flatten({$key => $val});
+        while (my($key, $val) = each(%{$pairs})) {
+            $key =~ s/(\w):(\d)/"$1.".($2+1)/gpe;
+            $key =~ s/\\//g;
+            unless (exists $ENV{$self->to_env_key($key)} && ! $self->override) {
+                $self->load({$self->to_env_key($key) => $val});
+                $self->{registry}{env}{$key} = $val;
+            }
         }
     }
 
@@ -229,7 +234,7 @@ Config::Environment - Application Configuration via Environment Variables
 
 =head1 VERSION
 
-version 0.000004
+version 0.000005
 
 =head1 SYNOPSIS
 
@@ -312,10 +317,16 @@ value overridden. This attribute is set to true by default.
 =head2 load
 
 The load method expects a hashref which it parses and generates environment
-variables from whether the exist or not and registers the formatted environment
+variables from whether they exist or not and registers the formatted environment
 structure. This method is called automatically on instantiation using the global
 ENV hash as an argument.
 
+    my $hash = {
+        APP_MODE => 'development',
+        APP_USER => 'vagrant',
+        APP_PORT => 9000
+    };
+
     $self->load($hash);
 
 =head2 param
@@ -330,6 +341,11 @@ form of a scalar, arrayref or hashref.
     my $item = $self->param($key);
     my $item = $self->param($key => $value);
 
+    # load parsed data from another configuration source, e.g. a config file
+    while (my($key, $val) = each(%$configuration) {
+        $self->param($key => $val);
+    }
+
 =head2 params
 
 The params method expects a list of keys which are used to locate the
